# NFEM Teaching Tool

![CI](https://github.com/ChairOfStructuralAnalysisTUM/nfem/workflows/CI/badge.svg) ![PyPI](https://img.shields.io/pypi/v/nfem?label=Version) [![codecov](https://codecov.io/gh/ChairOfStructuralAnalysisTUM/nfem/branch/master/graph/badge.svg)](https://codecov.io/gh/ChairOfStructuralAnalysisTUM/nfem) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/ChairOfStructuralAnalysisTUM/nfem/master?filepath=examples)


This is a lightweight python tool build for teaching non linear FEM analysis of 3D truss structures.

It can be either used in scripting mode or via an interactive user interface.

## User Manual

There is a short user manual available [here](https://nbviewer.jupyter.org/github/ChairOfStructuralAnalysisTUM/nfem/blob/master/user_manual/user_manual.ipynb).

## Prerequisites
* Python3 
* numpy
* matplotlib
* pyqt5

All the above mentioned packages can be easily optained by downloading e.g. [Anaconda](https://www.anaconda.com/distribution/).
